import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ProfileRoutingModule } from './profile-routing.module';
import { ProfileEditComponent } from './components/profile-edit/profile-edit.component';
import { MaterialModule } from '../material/material.module';
import { AuthService } from '../auth/services/auth/auth.service';
import { TranslateLoader, TranslateModule } from '@ngx-translate/core';
import { HttpLoaderFactory } from 'src/app/app.module';
import { HttpClient } from '@angular/common/http';
import { ProfileEditBasicsComponent } from './components/profile-edit-basics/profile-edit-basics.component';
import { ProfileEditCredentialsComponent } from './components/profile-edit-credentials/profile-edit-credentials.component';
import { ProfileEditSettingsComponent } from './components/profile-edit-settings/profile-edit-settings.component';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { NgStackFormsModule } from '@ng-stack/forms';
import { ProfileEditHealthComponent } from './components/profile-edit-health/profile-edit-health.component';
import { ProfileEditRolesComponent } from './components/profile-edit-roles/profile-edit-roles.component';
import { CountryService } from '../shared/services/country/country.service';

@NgModule({
    declarations: [
        ProfileEditComponent,
        ProfileEditBasicsComponent,
        ProfileEditCredentialsComponent,
        ProfileEditSettingsComponent,
        ProfileEditHealthComponent,
        ProfileEditRolesComponent,
    ],
    imports: [
        CommonModule,
        ProfileRoutingModule,
        FormsModule,
        ReactiveFormsModule,
        NgStackFormsModule,
        MaterialModule,
        TranslateModule.forChild({
            defaultLanguage: 'en',
            loader: {
                provide: TranslateLoader,
                useFactory: HttpLoaderFactory,
                deps: [HttpClient]
            }
        }),
    ],
    providers: [
        AuthService,
        CountryService,
    ],
})
export class ProfileModule { }
